@@ -1,4 +1,4 @@
-__version__ = '1.0'
+__version__ = '1.1dev'
 __author__ = "Simon Fell et al. reluctantly forked by idbentley"
 __credits__ = "Mad shouts to the sforce possie"
 __copyright__ = "GNU GPL 2."
@@ -34,7 +34,7 @@ gzipRequest=True    # are we going to gzip the request ?
 gzipResponse=True   # are we going to tell teh server to gzip the response ?
 forceHttp=False     # force all connections to be HTTP, for debugging
 
-_logger = logging.getLogger('pyforce')
+_logger = logging.getLogger('pyforce.{0}'.format(__name__))
 
 def makeConnection(scheme, host):
     if forceHttp or scheme.upper() == 'HTTP':
